@@ -95,6 +95,9 @@ CORE_CONFIG_SCHEMA = vol.Schema(
         vol.Optional(
             "configuration_version", default=CONFIGURATION_VERSION
         ): str,
+        vol.Optional("global_brightness", default=1.0): vol.All(
+            vol.Coerce(float), vol.Range(0, 1.0)
+        ),
     },
     extra=vol.ALLOW_EXTRA,
 )
@@ -190,7 +193,6 @@ def ensure_config_file(config_dir: str) -> str:
 
 
 def check_preset_file(config_dir: str) -> str:
-
     ensure_config_directory(config_dir)
     presets_path = get_preset_file(config_dir)
     if presets_path is None:
@@ -225,7 +227,6 @@ def load_config(config_dir: str) -> dict:
         f"Loading configuration file: {os.path.join(os.path.abspath(config_dir), CONFIG_FILE_NAME)}"
     )
     try:
-
         with open(config_file, encoding="utf-8") as file:
             config_json = json.load(file)
             try:
