@@ -372,7 +372,6 @@ class NetworkedDevice(Device):
 
 @BaseRegistry.no_registration
 class UDPDevice(NetworkedDevice):
-
     CONFIG_SCHEMA = vol.Schema(
         {
             vol.Required(
@@ -408,7 +407,6 @@ class AvailableCOMPorts:
 
 @BaseRegistry.no_registration
 class SerialDevice(Device):
-
     CONFIG_SCHEMA = vol.Schema(
         {
             vol.Required(
@@ -620,12 +618,14 @@ class Devices(RegistryLoader):
         if hasattr(device, "async_initialize"):
             await device.async_initialize()
 
+        device_config = device.config
+
         # Update and save the configuration
         self._ledfx.config["devices"].append(
             {
                 "id": device.id,
                 "type": device.type,
-                "config": device.config,
+                "config": device_config,
             }
         )
 
